from setuptools import setup

setup(
    name="quakehub",
    version="0.1.1",
    long_description="",
    long_description_content_type="text/markdown",
    packages=["quakehub"],
    install_requires=["numpy",  "h5py", "matplotlib", "pandas"],
)
